@@ -4,10 +4,10 @@ from django.conf import settings
 
 CKEDITOR_SETTINGS = getattr(settings, 'CKEDITOR_SETTINGS', {
     'language': '{{ language }}',
-    'toolbar': 'Basic',
-    'skin': 'kama',
+    'toolbar': 'CMS',
+    'skin': 'moono',
     'toolbarCanCollapse': False,
 })
 
-
+TEXT_SAVE_IMAGE_FUNCTION = getattr(settings, 'TEXT_SAVE_IMAGE_FUNCTION', 'djangocms_text_ckeditor.picture_save.create_picture_plugin')
 
